@@ -7,12 +7,13 @@ import pytest
 import xarray as xr
 
 from . import (
-    TestCase, assert_array_equal, assert_equal, raises_regex, requires_dask,
-    has_cftime, has_dask, has_cftime_or_netCDF4)
+    assert_array_equal, assert_equal, has_cftime, has_cftime_or_netCDF4,
+    has_dask, raises_regex, requires_dask)
 
 
-class TestDatetimeAccessor(TestCase):
-    def setUp(self):
+class TestDatetimeAccessor(object):
+    @pytest.fixture(autouse=True)
+    def setup(self):
         nt = 100
         data = np.random.rand(10, 10, nt)
         lons = np.linspace(0, 11, 10)
@@ -157,8 +158,11 @@ def times_3d(times):
 
 
 @pytest.mark.skipif(not has_cftime, reason='cftime not installed')
-@pytest.mark.parametrize('field', ['year', 'month', 'day', 'hour'])
+@pytest.mark.parametrize('field', ['year', 'month', 'day', 'hour',
+                                   'dayofyear', 'dayofweek'])
 def test_field_access(data, field):
+    if field == 'dayofyear' or field == 'dayofweek':
+        pytest.importorskip('cftime', minversion='1.0.2.1')
     result = getattr(data.time.dt, field)
     expected = xr.DataArray(
         getattr(xr.coding.cftimeindex.CFTimeIndex(data.time.values), field),
@@ -169,10 +173,13 @@ def test_field_access(data, field):
 
 @pytest.mark.skipif(not has_dask, reason='dask not installed')
 @pytest.mark.skipif(not has_cftime, reason='cftime not installed')
-@pytest.mark.parametrize('field', ['year', 'month', 'day', 'hour'])
+@pytest.mark.parametrize('field', ['year', 'month', 'day', 'hour',
+                                   'dayofyear', 'dayofweek'])
 def test_dask_field_access_1d(data, field):
     import dask.array as da
 
+    if field == 'dayofyear' or field == 'dayofweek':
+        pytest.importorskip('cftime', minversion='1.0.2.1')
     expected = xr.DataArray(
         getattr(xr.coding.cftimeindex.CFTimeIndex(data.time.values), field),
         name=field, dims=['time'])
@@ -185,10 +192,13 @@ def test_dask_field_access_1d(data, field):
 
 @pytest.mark.skipif(not has_dask, reason='dask not installed')
 @pytest.mark.skipif(not has_cftime, reason='cftime not installed')
-@pytest.mark.parametrize('field', ['year', 'month', 'day', 'hour'])
+@pytest.mark.parametrize('field', ['year', 'month', 'day', 'hour', 'dayofyear',
+                                   'dayofweek'])
 def test_dask_field_access(times_3d, data, field):
     import dask.array as da
 
+    if field == 'dayofyear' or field == 'dayofweek':
+        pytest.importorskip('cftime', minversion='1.0.2.1')
     expected = xr.DataArray(
         getattr(xr.coding.cftimeindex.CFTimeIndex(times_3d.values.ravel()),
                 field).reshape(times_3d.shape),
